# sd-geninfo

Python CLI for reading metadata embedded in images generated by Stable Diffusion.

## Dependencies

 - [Python 3.x](https://python.org)
 - [python-pillow/Pillow](https://github.com/python-pillow/Pillow)

## Installation

```sh
$  pip install sd-geninfo
```

## Usage

```
usage: sd-geninfo [-h] -i INPUT [-o OUTPUT]

Python CLI for reading metadata embedded in images generated by Stable Diffusion.

options:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
                        Path to input image from which to read metadata, will read from stdin if '-' is passed
  -o OUTPUT, --output OUTPUT
                        Optional output path for writing metadata to, defaults to stdout write metadata
  -c COLOR, --color COLOR
                        Whether to pretty print the json result in color, defaults to "--color=auto" which will pretty print when stdout is detected as a terminal, pass "--color=never" to force printing in plain text, pass "--color=always" to force pretty printing
  -m, --minify
                        Whether to minify the JSON before outputting it, false by default
```
